# metadata

Source: [config_map/core/metadata.k](https://url/to/source_code/config_map/core/metadata.k)

## Schema Metadata

Metadata is the base schema of all models, which contains data<br />that helps uniquely identify the object.

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**name**<br />The name of the resource.<br />Name must be unique within a namespace. It's required when creating<br />resources, although some resources may allow a client to request the<br />generation of an appropriate name automatically.<br />Name is primarily intended for creation idempotence and configuration<br />definition. Cannot be updated. More info:<br />http://kubernetes.io/docs/user-guide/identifiers\#names|str|Undefined|**required**|
|**labels**<br />Labels is a map of string keys and values that can be used to<br />organize and categorize (scope and select) objects.<br />May match selectors of replication controllers and services.<br />More info: http://kubernetes.io/docs/user-guide/labels|{str: str}|Undefined|optional|
|**annotations**<br />Annotations is an unstructured key value map stored with a<br />resource that may be set by external tools to store and retrieve<br />arbitrary metadata. They are not queryable and should be preserved<br />when modifying objects.<br />More info: http://kubernetes.io/docs/user-guide/annotations|{str: str}|Undefined|optional|
|**namespace**<br />Namespaces are intended for use in environments with many users spread<br />across multiple teams, or projects.<br />For clusters with a few to tens of users, you should not need to create<br />or think about namespaces at all. Start using namespaces when you need the features they provide.<br />More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/|str|Undefined|optional|
<!-- Auto generated by kcl-doc tool, please do not edit. -->
